@@ -224,6 +224,7 @@ def upload(identifier, files,
            retries=None,
            retries_sleep=None,
            debug=None,
+           validate_identifier=None,
            request_kwargs=None,
            **get_item_kwargs):
     """Upload files to an item. The item will be created if it does not exist.
@@ -276,6 +277,10 @@ def upload(identifier, files,
     :param debug: (optional) Set to True to print headers to stdout, and exit without
                   sending the upload request.
 
+    :type validate_identifier: bool
+    :param validate_identifier: (optional) Set to True to validate the identifier before
+                                uploading the file.
+
     :param \*\*kwargs: Optional arguments that ``get_item`` takes.
 
     :returns: A list of :py:class:`requests.Response` objects.
@@ -294,6 +299,7 @@ def upload(identifier, files,
                        retries=retries,
                        retries_sleep=retries_sleep,
                        debug=debug,
+                       validate_identifier=validate_identifier,
                        request_kwargs=request_kwargs)
 
 
@@ -478,6 +484,8 @@ def search_items(query,
                  fields=None,
                  sorts=None,
                  params=None,
+                 full_text_search=None,
+                 dsl_fts=None,
                  archive_session=None,
                  config=None,
                  config_file=None,
@@ -498,6 +506,15 @@ def search_items(query,
     :param params: (optional) The URL parameters to send with each request sent to the
                    Archive.org Advancedsearch Api.
 
+    :type full_text_search: bool
+    :param full_text_search: (optional) Beta support for querying the archive.org
+                             Full Text Search API [default: False].
+
+    :type dsl_fts: bool
+    :param dsl_fts: (optional) Beta support for querying the archive.org Full Text
+                    Search API in dsl (i.e. do not prepend ``!L `` to the
+                    ``full_text_search`` query [default: False].
+
     :type config: dict
     :param secure: (optional) Configuration options for session.
 
@@ -534,6 +551,8 @@ def search_items(query,
                                         fields=fields,
                                         sorts=sorts,
                                         params=params,
+                                        full_text_search=full_text_search,
+                                        dsl_fts=dsl_fts,
                                         request_kwargs=request_kwargs,
                                         max_retries=max_retries)
 
@@ -553,8 +572,8 @@ def configure(username=None, password=None, config_file=None, host=None):
     """
     username = input('Email address: ') if not username else username
     password = getpass('Password: ') if not password else password
-    config_file_path = config_module.write_config_file(
-        username, password, config_file, host)
+    auth_config = config_module.get_auth_config(username, password, host)
+    config_file_path = config_module.write_config_file(auth_config, config_file)
     return config_file_path
 
 
