@@ -2,7 +2,7 @@
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
-# Copyright (C) 2012-2019 Internet Archive
+# Copyright (C) 2012-2021 Internet Archive
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -21,7 +21,7 @@
 internetarchive.item
 ~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (C) 2012-2019 by Internet Archive.
+:copyright: (C) 2012-2021 by Internet Archive.
 :license: AGPL 3, see LICENSE for more details.
 """
 from __future__ import absolute_import, unicode_literals, print_function
@@ -32,7 +32,6 @@ from fnmatch import fnmatch
 from logging import getLogger
 from time import sleep
 import math
-from xml.dom.minidom import parseString
 from xml.parsers.expat import ExpatError
 
 try:
@@ -48,12 +47,15 @@ from requests import Response
 from tqdm import tqdm
 from requests.exceptions import HTTPError
 
-from internetarchive.utils import IdentifierListAsItems, get_md5, chunk_generator, \
-    IterableToFileAdapter, iter_directory, recursive_file_count, norm_filepath
+from internetarchive.utils import (IdentifierListAsItems, get_md5,
+                                   chunk_generator, IterableToFileAdapter,
+                                   iter_directory, recursive_file_count,
+                                   norm_filepath)
 from internetarchive.files import File
 from internetarchive.iarequest import MetadataRequest, S3Request
 from internetarchive.auth import S3Auth
-from internetarchive.utils import get_s3_xml_text, get_file_size, is_dir
+from internetarchive.utils import (get_s3_xml_text, get_file_size, is_dir,
+                                   validate_s3_identifier)
 
 log = getLogger(__name__)
 
@@ -107,11 +109,11 @@ class BaseItem(object):
         self.collection = IdentifierListAsItems(mc, self.session)
 
     def __eq__(self, other):
-        return self.item_metadata == other.item_metadata or \
-            (self.item_metadata.keys() == other.item_metadata.keys() and
-             all(self.item_metadata[x] == other.item_metadata[x]
-                 for x in self.item_metadata
-                 if x not in self.EXCLUDED_ITEM_METADATA_KEYS))
+        return (self.item_metadata == other.item_metadata
+                or (self.item_metadata.keys() == other.item_metadata.keys()
+                    and all(self.item_metadata[x] == other.item_metadata[x]
+                            for x in self.item_metadata
+                            if x not in self.EXCLUDED_ITEM_METADATA_KEYS)))
 
     def __le__(self, other):
         return self.identifier <= other.identifier
@@ -182,8 +184,8 @@ class Item(BaseItem):
 
         if self.metadata.get('title'):
             # A copyable link to the item, in MediaWiki format
-            self.wikilink = '* [{0.urls.details} {0.identifier}] ' \
-                            '-- {0.metadata[title]}'.format(self)
+            self.wikilink = ('* [{0.urls.details} {0.identifier}] '
+                             '-- {0.metadata[title]}').format(self)
 
     class URLs:
         def __init__(self, itm_obj):
@@ -212,8 +214,8 @@ class Item(BaseItem):
             self._paths.append(path)
 
         def __str__(self):
-            return "URLs ({1}) for {0.identifier}" \
-                   .format(self._itm_obj, ', '.join(self._paths))
+            return ("URLs ({1}) for {0.identifier}"
+                    .format(self._itm_obj, ', '.join(self._paths)))
 
     def refresh(self, item_metadata=None, **kwargs):
         if not item_metadata:
@@ -230,15 +232,10 @@ class Item(BaseItem):
         """
         url = '{}//{}/services/check_identifier.php'.format(self.session.protocol,
                                                             self.session.host)
-        params = dict(identifier=self.identifier)
-        r = self.session.get(url, params=params)
-        p = parseString(r.text)
-        result = p.getElementsByTagName('result')[0]
-        available = result.attributes['code'].value
-        if available == 'not_available':
-            return False
-        else:
-            return True
+        params = dict(output='json', identifier=self.identifier)
+        response = self.session.get(url, params=params)
+        availability = response.json()['code']
+        return availability == 'available'
 
     def get_task_summary(self, params=None, request_kwargs=None):
         """Get a summary of the item's pending tasks.
@@ -518,9 +515,9 @@ class Item(BaseItem):
         return File(self, file_name, file_metadata)
 
     def get_files(self, files=None, formats=None, glob_pattern=None, on_the_fly=None):
-        files = [] if not files else files
-        formats = [] if not formats else formats
-        on_the_fly = False if not on_the_fly else True
+        files = files or []
+        formats = formats or []
+        on_the_fly = bool(on_the_fly)
 
         if not isinstance(files, (list, tuple, set)):
             files = [files]
@@ -648,17 +645,17 @@ class Item(BaseItem):
         :rtype: bool
         :returns: True if if all files have been downloaded successfully.
         """
-        dry_run = False if dry_run is None else dry_run
-        verbose = False if verbose is None else verbose
-        silent = False if silent is None else silent
-        ignore_existing = False if ignore_existing is None else ignore_existing
-        ignore_errors = False if not ignore_errors else ignore_errors
-        checksum = False if checksum is None else checksum
-        no_directory = False if no_directory is None else no_directory
-        return_responses = False if not return_responses else True
-        no_change_timestamp = False if not no_change_timestamp else no_change_timestamp
-        ignore_history_dir = False if ignore_history_dir is None else ignore_history_dir
-        params = None if not params else params
+        dry_run = bool(dry_run)
+        verbose = bool(verbose)
+        silent = bool(silent)
+        ignore_existing = bool(ignore_existing)
+        ignore_errors = bool(ignore_errors)
+        checksum = bool(checksum)
+        no_directory = bool(no_directory)
+        return_responses = bool(return_responses)
+        no_change_timestamp = bool(no_change_timestamp)
+        ignore_history_dir = bool(ignore_history_dir)
+        params = params or None
 
         if not dry_run:
             if item_index and verbose is True:
@@ -739,10 +736,7 @@ class Item(BaseItem):
             else:
                 print(' - success')
 
-        if return_responses:
-            return responses
-        else:
-            return errors
+        return responses if return_responses else errors
 
     def modify_metadata(self, metadata,
                         target=None,
@@ -784,16 +778,16 @@ class Item(BaseItem):
             >>> md = dict(new_key='new_value', foo=['bar', 'bar2'])
             >>> item.modify_metadata(md)
 
-        :rtype: dict
+        :rtype: Response
         :returns: A dictionary containing the status_code and response
                   returned from the Metadata API.
         """
-        append = False if append is None else append
-        access_key = self.session.access_key if not access_key else access_key
-        secret_key = self.session.secret_key if not secret_key else secret_key
-        debug = False if debug is None else debug
-        headers = dict() if headers is None else headers
-        request_kwargs = {} if not request_kwargs else request_kwargs
+        append = bool(append)
+        access_key = access_key or self.session.access_key
+        secret_key = secret_key or self.session.secret_key
+        debug = bool(debug)
+        headers = headers or {}
+        request_kwargs = request_kwargs or {}
 
         _headers = self.session.headers.copy()
         _headers.update(headers)
@@ -859,6 +853,7 @@ class Item(BaseItem):
                     retries=None,
                     retries_sleep=None,
                     debug=None,
+                    validate_identifier=None,
                     request_kwargs=None):
         """Upload a single file to an item. The item will be created
         if it does not exist.
@@ -910,6 +905,10 @@ class Item(BaseItem):
         :param debug: (optional) Set to True to print headers to stdout, and
                       exit without sending the upload request.
 
+        :type validate_identifier: bool
+        :param validate_identifier: (optional) Set to True to validate the identifier before
+                                    uploading the file.
+
         Usage::
 
             >>> import internetarchive
@@ -919,21 +918,22 @@ class Item(BaseItem):
             True
         """
         # Set defaults.
-        headers = {} if headers is None else headers
-        metadata = {} if metadata is None else metadata
-        file_metadata = {} if file_metadata is None else file_metadata
-        access_key = self.session.access_key if access_key is None else access_key
-        secret_key = self.session.secret_key if secret_key is None else secret_key
-        queue_derive = True if queue_derive is None else queue_derive
-        verbose = False if verbose is None else verbose
-        verify = False if not verify else verify
-        delete = False if delete is None else delete
+        headers = headers or {}
+        metadata = metadata or {}
+        file_metadata = file_metadata or {}
+        access_key = access_key or self.session.access_key
+        secret_key = secret_key or self.session.secret_key
+        queue_derive = bool(queue_derive)
+        verbose = bool(verbose)
+        verify = bool(verify)
+        delete = bool(delete)
         # Set checksum after delete.
-        checksum = True if delete else checksum
-        retries = 0 if retries is None else retries
-        retries_sleep = 30 if retries_sleep is None else retries_sleep
-        debug = False if debug is None else debug
-        request_kwargs = {} if request_kwargs is None else request_kwargs
+        checksum = delete or checksum
+        retries = retries or 0
+        retries_sleep = retries_sleep or 30
+        debug = bool(debug)
+        validate_identifier = bool(validate_identifier)
+        request_kwargs = request_kwargs or {}
         if 'timeout' not in request_kwargs:
             request_kwargs['timeout'] = 120
         md5_sum = None
@@ -944,10 +944,7 @@ class Item(BaseItem):
             filename = body
             body = open(body, 'rb')
         else:
-            if key:
-                filename = key
-            else:
-                filename = body.name
+            filename = key or body.name
 
         size = get_file_size(body)
 
@@ -959,6 +956,8 @@ class Item(BaseItem):
             _headers['x-archive-size-hint'] = str(size)
 
         # Build IA-S3 URL.
+        if validate_identifier:
+            validate_s3_identifier(self.identifier)
         key = norm_filepath(filename).split('/')[-1] if key is None else key
         base_url = '{0.session.protocol}//s3.us.archive.org/{0.identifier}'.format(self)
         url = '{0}/{1}'.format(
@@ -1112,6 +1111,7 @@ class Item(BaseItem):
                retries=None,
                retries_sleep=None,
                debug=None,
+               validate_identifier=None,
                request_kwargs=None):
         """Upload files to an item. The item will be created if it
         does not exist.
@@ -1182,8 +1182,8 @@ class Item(BaseItem):
                     file_metadata = f.copy()
                     del file_metadata['name']
                     f = f['name']
-            if (isinstance(f, string_types) and is_dir(f)) \
-                    or (isinstance(f, tuple) and is_dir(f[-1])):
+            if ((isinstance(f, string_types) and is_dir(f))
+                    or (isinstance(f, tuple) and is_dir(f[-1]))):
                 if isinstance(f, tuple):
                     remote_dir_name = f[0].strip('/')
                     f = f[-1]
@@ -1218,6 +1218,7 @@ class Item(BaseItem):
                                             retries=retries,
                                             retries_sleep=retries_sleep,
                                             debug=debug,
+                                            validate_identifier=validate_identifier,
                                             request_kwargs=request_kwargs)
                     responses.append(resp)
             else:
@@ -1251,6 +1252,7 @@ class Item(BaseItem):
                                         retries=retries,
                                         retries_sleep=retries_sleep,
                                         debug=debug,
+                                        validate_identifier=validate_identifier,
                                         request_kwargs=request_kwargs)
                 responses.append(resp)
         return responses
